Installation
============

You can install ``simple_openid_connect`` from `PyPi <https://pypi.org/project/simple_openid_connect/>`_::

    $ pip install simple_openid_connect

Alternatively, installing the latest development version from source can also be done::

    $ pip install git+https://github.com/fsinfuhh/py_simple_openid_connect.git
